/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package com.vci.ubcs.code.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.vci.ubcs.code.entity.CodeAllcode;
import com.vci.ubcs.code.service.ICodeAllcodeService;
import com.vci.ubcs.code.vo.pagemodel.CodeAllcodeVO;
import com.vci.ubcs.code.wrapper.CodeAllcodeWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 * 全部码值 控制器
 *
 * @author ludc
 * @since 2023-04-03
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-code/CodeAllcode")
@Api(value = "全部码值", tags = "全部码值接口")
public class CodeAllcodeController extends BladeController {

	private final ICodeAllcodeService CodeAllcodeService;

	/**
	 * 全部码值 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入CodeAllcode")
	public R<CodeAllcodeVO> detail(CodeAllcode CodeAllcode) {
		CodeAllcode detail = CodeAllcodeService.getOne(Condition.getQueryWrapper(CodeAllcode));
		return R.data(CodeAllcodeWrapper.build().entityVO(detail));
	}
	/**
	 * 全部码值 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入CodeAllcode")
	public R<IPage<CodeAllcodeVO>> list(CodeAllcode CodeAllcode, Query query) {
		IPage<CodeAllcode> pages = CodeAllcodeService.page(Condition.getPage(query), Condition.getQueryWrapper(CodeAllcode));
		return R.data(CodeAllcodeWrapper.build().pageVO(pages));
	}

	/**
	 * 全部码值 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入CodeAllcode")
	public R<IPage<CodeAllcodeVO>> page(CodeAllcodeVO CodeAllcode, Query query) {
		IPage<CodeAllcodeVO> pages = CodeAllcodeService.selectCodeAllcodePage(Condition.getPage(query), CodeAllcode);
		return R.data(pages);
	}

	/**
	 * 全部码值 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入CodeAllcode")
	public R save(@Valid @RequestBody CodeAllcode codeAllcode) {
		return R.status(CodeAllcodeService.save(codeAllcode));
	}

	/**
	 * 全部码值 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入CodeAllcode")
	public R update(@Valid @RequestBody CodeAllcode codeAllcode) {
		return R.status(CodeAllcodeService.updateById(codeAllcode));
	}

	/**
	 * 全部码值 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入CodeAllcode")
	public R submit(@Valid @RequestBody CodeAllcode codeAllcode) {
		return R.status(CodeAllcodeService.saveOrUpdate(codeAllcode));
	}

	/**
	 * 全部码值 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(CodeAllcodeService.removeBatchByIds(Func.toLongList(ids)));
	}


}
