/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package com.vci.ubcs.code.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.vci.ubcs.code.dto.CodeRuleDTO;
import com.vci.ubcs.code.entity.CodeRule;
import com.vci.ubcs.code.service.ICodeRuleService;
import com.vci.ubcs.code.vo.pagemodel.CodeRuleVO;
import com.vci.ubcs.code.wrapper.CodeRuleWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 * 编码规则 控制器
 *
 * @author ludc
 * @since 2023-04-03
 */
@RestController
@AllArgsConstructor
@RequestMapping("/mdmRule")
@Api(value = "编码规则", tags = "编码规则接口")
public class CodeRuleController extends BladeController {

	private final ICodeRuleService codeRuleService;

	/**
	 * 编码规则 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入codeRule")
	public R<CodeRuleVO> detail(CodeRule codeRule) {
		CodeRule detail = codeRuleService.getOne(Condition.getQueryWrapper(codeRule));
		return R.data(CodeRuleWrapper.build().entityVO(detail));
	}
	/**
	 * 编码规则 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入codeRuleVO")
	public R<IPage<CodeRuleVO>> list(CodeRule codeRule, Query query) {
		IPage<CodeRule> pages = codeRuleService.page(Condition.getPage(query), Condition.getQueryWrapper(codeRule));
		return R.data(CodeRuleWrapper.build().pageVO(pages));
	}

	/**
	 * 编码规则 自定义分页
	 */
	@GetMapping("/gridCodeRule")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入CodeRule")
	public R<IPage<CodeRuleVO>> page(CodeRuleVO CodeRule, Query query) {
		IPage<CodeRuleVO> pages = codeRuleService.selectPlCodeRulePage(Condition.getPage(query.setDescs("CREATETIME")), CodeRule);
		return R.data(pages);
	}

	/**
	 * 增加 主数据编码规则
	 * @param codeRuleDTO 主数据编码规则数据传输对象
	 * @return 执行结果，success为true表示成功，msg是失败的提示信息，obj是添加完成后的显示对象
	 */
	@PostMapping("/addCode")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入CodeRule")
	public R save(@Valid @RequestBody CodeRuleDTO codeRuleDTO) {
		return R.status(codeRuleService.addSave(codeRuleDTO));
	}

	/**
	 * 修改 主数据编码规则
	 * @param codeRuleDTO 主数据编码规则数据传输对象
	 * @return 执行结果，success为true表示成功，msg是失败的提示信息，obj是添加完成后的显示对象
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入CodeRule")
	public R update(@Valid @RequestBody CodeRuleDTO codeRuleDTO) {
		return R.status(codeRuleService.editSave(codeRuleDTO));
	}

	/**
	 * 编码规则 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入CodeRule")
	public R submit(@Valid @RequestBody CodeRule codeRule) {
		return R.status(codeRuleService.saveOrUpdate(codeRule));
	}

	/**
	 * 删除主数据编码规则
	 * @param codeRuleDTO 主数据编码规则数据传输对象，oid和ts需要传输
	 * @return 删除结果反馈：：success：成功，fail：失败
	 */
	@DeleteMapping( "/deleteData")
	public R delCodeRule(@Valid @RequestBody CodeRuleDTO codeRuleDTO) {
		return codeRuleService.deleteCodeRule(codeRuleDTO);
	}

}
