package com.vci.ubcs.code.enumpack;

import com.vci.ubcs.code.annotation.BaseEnum;
import com.vci.ubcs.code.constant.MdmEnumIdConstant;
import com.vci.ubcs.com.vci.starter.annotation.VciEnum;

/**
 * 码段的类型
 * @author weidy
 * @date 2022-1-20
 */
@VciEnum(name = MdmEnumIdConstant.CODE_SEC_TYPE,text = "码段的类型",description = "")
public enum CodeSecTypeEnum implements BaseEnum {

	/**
	 * 固定码段
	 */
	CODE_FIXED_SEC("codefixedsec","固定码段"),

	/**
	 * 可变码段
	 */
	CODE_VARIABLE_SEC("codevariablesec","可变码段"),
	/**
	 * 日期码段
	 */
	CODE_DATE_SEC("codedatasec","日期码段"),
	/**
	 * 分类码段
	 */
	CODE_CLASSIFY_SEC("codeclassifysec","分类码段"),
	/**
	 * 属性码段
	 */
	CODE_ATTR_SEC("codeattrsec","属性码段"),
	/**
	 * 流水码段
	 */
	CODE_SERIAL_SEC("codeserialsec","流水码段"),

	/**
	 * 层级码段
	 */
	CODE_LEVEL_SEC("codelevelsec","层级码段"),

	/**
	 * 引用码段
	 */
	CODE_REFER_SEC("coderefersec","引用码段")
	;

	/**
	 * 枚举的值
	 */
	private String value;

	/**
	 * 枚举显示文本
	 */
	private String text;

	/**
	 * 获取枚举值
	 *
	 * @return 枚举值
	 */
	@Override
	public String getValue() {
		return value;
	}

	/**
	 * 设置枚举值
	 *
	 * @param value 枚举值
	 */
	public void setValue(String value) {
		this.value = value;
	}

	/**
	 * 获取枚举显示文本
	 *
	 * @return 显示文本
	 */
	@Override
	public String getText() {
		return text;
	}

	/**
	 * 设置显示文本
	 *
	 * @param text 显示文本
	 */
	public void setText(String text) {
		this.text = text;
	}

	/**
	 * 构造函数
	 *
	 * @param value 值
	 * @param text  显示文本
	 */
	private CodeSecTypeEnum(String value, String text) {
		this.value = value;
		this.text = text;
	}

	/**
	 * 根据名称获取对应的枚举值
	 *
	 * @param text 名称
	 * @return 枚举值
	 */
	public static String getValueByText(String text) {
		for (CodeSecTypeEnum wenum : CodeSecTypeEnum.values()) {
			if (wenum.getText().equalsIgnoreCase(text)) {
				return wenum.getValue();
			}
		}
		return "";
	}

	/**
	 * 根据枚举值获取名称
	 *
	 * @param value 枚举值
	 * @return 名称
	 */
	public static String getTextByValue(String value) {
		for (CodeSecTypeEnum wenum : CodeSecTypeEnum.values()) {
			if (wenum.getValue().equalsIgnoreCase(value)) {
				return wenum.getText();
			}
		}
		return "";
	}

	/**
	 * 根据枚举值获取枚举对象
	 *
	 * @param value 枚举值
	 * @return 枚举对象，不存在时候返回null
	 */
	public static CodeSecTypeEnum forValue(String value) {
		for (CodeSecTypeEnum wenum : CodeSecTypeEnum.values()) {
			if (wenum.getValue().equalsIgnoreCase(value)) {
				return wenum;
			}
		}
		return null;
	}

}

