package com.vci.ubcs.code.lifecycle;


import com.vci.ubcs.code.annotation.BaseEnum;
import com.vci.ubcs.code.constant.FrameWorkDefaultValueConstant;

/**
 * 编码规则的生命周期
 * @author weidy
 * @date 2022-2-23
 */
/*@VciLifeCycle(name = MdmLifeCycleConstant.CODE_RULE_LC,text = "编码规则板生命周期",description = "",startStatus = FrameWorkDefaultValueConstant.FRAMEWORK_RELEASE_EDITING,
        translations={
            @VciLifeCycleTrans(source = FrameWorkDefaultValueConstant.FRAMEWORK_RELEASE_EDITING,target =FrameWorkDefaultValueConstant.FRAMEWORK_RELEASE_RELEASED,name = "发布"),
            @VciLifeCycleTrans(source = FrameWorkDefaultValueConstant.FRAMEWORK_RELEASE_RELEASED,target = FrameWorkDefaultValueConstant.FRAMEWORK_DATA_DISABLED,name = "作废"),
            @VciLifeCycleTrans(source = FrameWorkDefaultValueConstant.FRAMEWORK_RELEASE_EDITING,target = FrameWorkDefaultValueConstant.FRAMEWORK_DATA_DISABLED,name = "未发布直接停用"),
            @VciLifeCycleTrans(source = FrameWorkDefaultValueConstant.FRAMEWORK_DATA_DISABLED,target = FrameWorkDefaultValueConstant.FRAMEWORK_RELEASE_RELEASED,name = "停用后再次生效")
        }
)*/
public enum CodeRuleLC implements BaseEnum {

    /**
     * 编辑中
     */
    EDITING(FrameWorkDefaultValueConstant.FRAMEWORK_RELEASE_EDITING,"编辑中"),

    /**
     * 已发布
     */
    RELEASED(FrameWorkDefaultValueConstant.FRAMEWORK_RELEASE_RELEASED,"已发布"),

    /**
     * 停用
     */
    DISABLED(FrameWorkDefaultValueConstant.FRAMEWORK_DATA_DISABLED,"停用");

    /**
     * 枚举的值
     */
    private String value;

    /**
     * 枚举显示文本
     */
    private String text;

    /**
     * 获取枚举值
     *
     * @return 枚举值
     */
    @Override
    public String getValue() {
        return value;
    }

    /**
     * 设置枚举值
     *
     * @param value 枚举值
     */
    public void setValue(String value) {
        this.value = value;
    }

    /**
     * 获取枚举显示文本
     *
     * @return 显示文本
     */
    @Override
    public String getText() {
        return text;
    }

    /**
     * 设置显示文本
     *
     * @param text 显示文本
     */
    public void setText(String text) {
        this.text = text;
    }

    /**
     * 构造函数
     *
     * @param value 值
     * @param text  显示文本
     */
    private CodeRuleLC(String value, String text) {
        this.value = value;
        this.text = text;
    }

    /**
     * 根据名称获取对应的枚举值
     *
     * @param text 名称
     * @return 枚举值
     */
    public static String getValueByText(String text) {
        for (CodeRuleLC wenum : CodeRuleLC.values()) {
            if (wenum.getText().equalsIgnoreCase(text)) {
                return wenum.getValue();
            }
        }
        return "";
    }

    /**
     * 根据枚举值获取名称
     *
     * @param value 枚举值
     * @return 名称
     */
    public static String getTextByValue(String value) {
        for (CodeRuleLC wenum : CodeRuleLC.values()) {
            if (wenum.getValue().equalsIgnoreCase(value)) {
                return wenum.getText();
            }
        }
        return "";
    }

    /**
     * 根据枚举值获取枚举对象
     *
     * @param value 枚举值
     * @return 枚举对象，不存在时候返回null
     */
    public static CodeRuleLC forValue(String value) {
        for (CodeRuleLC wenum : CodeRuleLC.values()) {
            if (wenum.getValue().equalsIgnoreCase(value)) {
                return wenum;
            }
        }
        return null;
    }
}

