package com.vci.ubcs.system.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.vci.ubcs.system.service.ICombinationService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import com.vci.ubcs.system.entity.Combination;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * 密码组合方式表(Combination)表控制层
 *
 * @author makejava
 * @since 2023-03-20 15:23:16
 */
@ApiIgnore
@AllArgsConstructor
@RestController
@Api(value = "密码组合方式", tags = "接口")
@RequestMapping("/combination")
public class CombinationController {

	/**
	 * 服务对象
	 */
	@Resource
	private final ICombinationService combinationService;

	/**
	 * 分页查询
	 *
	 * @param combination 筛选条件
	 * @param query      分页对象
	 * @return 查询结果
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "分页查询", notes = "传入combination，分页参数query")
	public R<IPage<Combination>> queryByPage(Combination combination, Query query) {
		IPage<Combination> pages = combinationService.page(Condition.getPage(query), Condition.getQueryWrapper(combination));
		return R.data(pages);
	}

	/**
	 * 下拉数据源
	 */
	@GetMapping("/select")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "下拉数据源")
	public R<List> select() {
		List<Map<String, Object>> map = combinationService.selectMaps();
		return R.data(map);
	}

	/**
	 * 通过主键查询单条数据
	 *
	 * @param id 主键
	 * @return 单条数据
	 */
	@GetMapping("/one")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "通过主键查询单条数据", notes = "传入id")
	public ResponseEntity<Combination> queryById(@ApiParam(value = "组合方式ID", required = true) @RequestParam Long id) {
		return ResponseEntity.ok(this.combinationService.queryById(id));
	}

	/**
	 * 新增和修改数据
	 *
	 * @param combination 实体
	 * @return 新增结果
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增和修改数据", notes = "传入combination")
	public R submit(@Valid @RequestBody Combination combination) {
		return R.status(combinationService.submit(combination));
	}

	/**
	 * 删除数据
	 *
	 * @param ids 主键
	 * @return 删除是否成功
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public ResponseEntity<Boolean> deleteById(@ApiParam(value = "主键集合", required = true) @RequestParam List<String> ids) {
		return ResponseEntity.ok(this.combinationService.deleteByIds(ids));
	}

}

