package com.vci.ubcs.system.controller;

import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.vci.ubcs.system.service.IStrategyService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tenant.annotation.NonDS;
import org.springblade.core.tool.api.R;
import com.vci.ubcs.system.entity.Strategy;
import org.springframework.data.domain.Page;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;

/**
 * 密码策略(Strategy)表控制层
 *
 * @author makejava
 * @since 2023-03-20 16:45:31
 */
@NonDS
@ApiIgnore
@AllArgsConstructor
@RestController
@RequestMapping("/strategy")
@Api(value = "密码策略", tags = "接口")
public class StrategyController {

	/**
	 * 服务对象
	 */
	@Resource
	private IStrategyService strategyService;

	/**
	 * 分页查询
	 *
	 * @param query 分页对象
	 * @return 查询结果
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "分页查询", notes = "传入分页参数query")
	public R<Page<Strategy>> queryByPage(Query query) {
		Page<Strategy> strategyPage = strategyService.queryAllByPage(query);
		return R.data(strategyPage);
	}

	/**
	 * 查询默认密码策略
	 *
	 * @return 查询结果
	 */
	@GetMapping("/default")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "查询默认密码策略")
	public R<Strategy> queryByIsDefault() {
		Strategy strategy = strategyService.queryByIsDefault();
		return R.data(strategy);
	}

	/**
	 * 通过主键查询单条数据
	 *
	 * @param id 主键
	 * @return 单条数据
	 */
	@GetMapping("/one")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "通过主键查询单条数据", notes = "传入id")
	public ResponseEntity<Strategy> queryById(@ApiParam(value = "密码策略ID", required = true) @RequestParam String id) {
		return ResponseEntity.ok(this.strategyService.queryById(id));
	}

	/**
	 * 新增和修改数据
	 *
	 * @param strategy 实体
	 * @return 新增结果
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "新增或修改数据", notes = "传入strategy")
	public ResponseEntity<Boolean> submit(@Valid @RequestBody Strategy strategy) {
		return ResponseEntity.ok(this.strategyService.submit(strategy));
	}

	/**
	 * 删除数据
	 *
	 * @param ids 主键
	 * @return 删除是否成功
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "删除", notes = "传入ids")
	public ResponseEntity<Boolean> deleteById(@ApiParam(value = "主键集合", required = true) @RequestParam List<String> ids) {
		return ResponseEntity.ok(this.strategyService.deleteByIds(ids));
	}

	/**
	 * 根据用户id查询密码策略
	 *
	 * @param userId 实体
	 * @return 新增结果
	 */
	@PostMapping("/query-userid")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "根据用户id查询密码策略", notes = "传入userId")
	public R<Strategy> queryByUserId(@Valid @RequestParam Long userId) {
		return R.data(this.strategyService.queryByUserId(userId));
	}

}

