package com.vci.ubcs.system.controller;

import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.vci.ubcs.system.service.IUserPwdstrategyService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springblade.core.tenant.annotation.NonDS;
import com.vci.ubcs.system.vo.UserPwdstrategyVO;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.annotation.Resource;
import javax.validation.Valid;

/**
 * 用户密码策略关联(UserPwdstrategy)表控制层
 *
 * @author ludc
 * @since 2023-03-20 15:23:24
 */
@NonDS
@ApiIgnore
@AllArgsConstructor
@RestController
@RequestMapping("/user-pwdstrategy")
@Api(value = "用户密码安全策略关联表", tags = "接口")
public class UserPwdstrategyController {

	@Resource
	private IUserPwdstrategyService userPwdstrategyService;

	/**
	 * 新增和修改数据
	 *
	 * @param userPwdstrategyVO 实体
	 * @return 新增结果
	 */
	@PutMapping("/insert")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "新增数据", notes = "传入userPwdstrategy")
	public ResponseEntity<Boolean> insert(@Valid @RequestBody UserPwdstrategyVO userPwdstrategyVO) {
		return ResponseEntity.ok(this.userPwdstrategyService.submit(userPwdstrategyVO));
	}

	/**
	 * 新增和修改数据
	 *
	 * @param userPwdstrategyVO 实体
	 * @return 新增结果
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "修改数据", notes = "传入userPwdstrategy")
	public ResponseEntity<Boolean> update(@Valid @RequestBody UserPwdstrategyVO userPwdstrategyVO) {
		return ResponseEntity.ok(this.userPwdstrategyService.submit(userPwdstrategyVO));
	}



}
