package com.vci.ubcs.system.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.vci.ubcs.system.service.IValueRangeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tenant.annotation.NonDS;
import org.springblade.core.tool.api.R;
import com.vci.ubcs.system.entity.ValueRange;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;

/**
 * (ValueRangeController)表控制层
 *
 * @author ludc
 * @since 2023-03-20 15:23:24
 */
@NonDS
@ApiIgnore
@AllArgsConstructor
@RestController
@RequestMapping("/value-range")
@Api(value = "密码组合方式取值", tags = "接口")
public class ValueRangeController {

	/**
	 * 服务对象
	 */
	@Resource
	private IValueRangeService valueRangeService;

	@GetMapping("/list")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入dataScope")
	public R<List<ValueRange>> queryByList() {
		return R.data(valueRangeService.queryByAll());
	}

	/**
	 * 分页查询
	 *
	 * @param valueRange 筛选条件
	 * @param query      分页对象
	 * @return 查询结果
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页查询", notes = "传入valueRange，分页参数query")
	public R<IPage<ValueRange>> queryByPage(ValueRange valueRange, Query query) {
		IPage<ValueRange> pages = valueRangeService.page(Condition.getPage(query), Condition.getQueryWrapper(valueRange));
		return R.data(pages);
	}

	/**
	 * 新增和修改数据
	 *
	 * @param valueRange 实体
	 * @return 新增结果
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "新增和修改数据", notes = "传入valueRange")
	public ResponseEntity<Boolean> submit(@Valid @RequestBody ValueRange valueRange) {
		return ResponseEntity.ok(this.valueRangeService.submit(valueRange));
	}

	/**
	 * 删除数据
	 *
	 * @param ids 主键
	 * @return 删除是否成功
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public ResponseEntity<Boolean> deleteById(@ApiParam(value = "主键集合", required = true) @RequestParam List<String> ids) {
		return ResponseEntity.ok(this.valueRangeService.deleteByIds(ids));
	}

}

